```{include} ../README.md

```

```{toctree}
:caption: Getting Started
:maxdepth: 2

installation
dummy_vs_real
changelog
```

```{toctree}
:caption: API Documentation
:maxdepth: 2
:glob:

autoapi/evo2_mcp/index
```
